-- Scalar function returning duration of a voyage in days, 
-- or 0 if information is not available
create function "voc".duration( pnumber integer, psup char(1)) 
returns integer
begin
	declare dep date, arr date;
	set dep = (select departure_date
	   from "voc".voyages where number = pnumber and number_sup = psup);
	set arr = (select arrival_date
	   from "voc".voyages where number = pnumber and number_sup = psup);
	if (dep is null or arr is null)
	   then return 0;
	else return arr - dep;   
	end if;
end;			  

select "voc".duration(8000,'');

select number, boatname, duration(number, number_sup) as duration
from "voc".voyages 
where duration(number, number_sup) > 100 
order by duration limit 5 ;


-- Table-valued function returning total cargo per chamber for a given year

create function "voc".invoicesperchamber (pyear integer)
returns table (chamber char(1), total_invoices bigint)
begin
return table( select i.chamber, sum(i.invoice)
	   from "voc".voyages as v join "voc".invoices as i 
		on v.number = i.number and v.number_sup = i.number_sup
	   where extract (year from v.arrival_date) = pyear
	   group by i.chamber);
end;

select * from "voc".invoicesperchamber(1760) as a
order by total_invoices desc;
