
select number,boatname,tonnage,chamber,departure_date,departure_harbour,
	   arrival_date,arrival_harbour,next_voyage
from "voc".voyages where number = 101;

-- All voyages of ship named 'STAR':
select number,number_sup,trip,boatname,tonnage,chamber,
	   departure_date,departure_harbour,arrival_date,arrival_harbour,next_voyage, particulars
from voyages where boatname = 'STAR'
order by departure_date;

-- The top 10 ships wrt number of trips:
select boatname, count(*) as cnt
from voyages
group by boatname
order by cnt desc
limit 10;

-- The second biggest ship
select distinct boatname, tonnage
from voyages order by tonnage desc
limit 1 offset 1;

-- The revenue of chamber Amsterdam for year 1777:
select i.chamber, i.invoice
from voyages as v join invoices as i on v.number = i.number
	 and v.number_sup = i.number_sup
where extract (year from v.arrival_date) = 1777 
and i.chamber = 'A';


-- Create view combining all data about passengers and crew.
CREATE VIEW "voc".onboard_people AS
SELECT * FROM (
SELECT 'craftsmen' AS type, craftsmen.* FROM "voc".craftsmen
UNION ALL
SELECT 'impotenten' AS type, impotenten.* FROM "voc".impotenten
UNION ALL
SELECT 'passengers' AS type, passengers.* FROM "voc".passengers
UNION ALL
SELECT 'seafarers' AS type, seafarers.* FROM "voc".seafarers
UNION ALL
SELECT 'soldiers' AS type, soldiers.* FROM "voc".soldiers
UNION ALL
 SELECT 'total' AS type, total.* FROM "voc".total
 ) AS onboard_people_table;

select * from onboard_people where number=8000;

-- Create view summarizing passengers and crew in 1 row per voyage.
create view total_onboard as
select number, number_sup, sum(onboard_at_departure) as total_onboard_at_departure,
		sum(death_at_cape) as total_death_at_cape,
		sum(left_at_cape) as total_left_at_cape,
		sum(onboard_at_cape) as total_onboard_at_cape,
		sum(death_during_voyage) as total_death_during_voyage,
		sum(onboard_at_arrival) as total_onboard_at_arrival
from "voc".onboard_people
group by number, number_sup;

select * from total_onboard where number=8000;

select number,total_death_at_cape from total_onboard 
where total_death_at_cape = 
	  (select max(total_death_at_cape) from total_onboard );

-- Transaction support
START TRANSACTION;

create table lastvoyages
as select number, boatname, departure_date, arrival_date
from voyages
where  extract (year from arrival_date) = 1795
with  data;

select * from lastvoyages;

COMMIT;

START TRANSACTION;
insert into lastvoyages
select number, boatname, departure_date, arrival_date
from voyages
where  extract (year from arrival_date) = 1794;

select * from lastvoyages;

ROLLBACK;
select * from lastvoyages;
